@@ -1,37 +1,14 @@
 import click
-from womg.propagation import Propagation
-from womg.network.tn import TN
+from womg_core import womgc
 from womg.topic.lda import LDA
-from womg.diffusion.tlt import TLT
-from womg.utils.distributions import set_seed
-from womg.utils.saver import TxtSaver
-
-
-
-
-def save(network_model, topic_model, diffusion_model,
-         path, save_all,
-         save_int, save_infl, save_keyw):
-    saver = TxtSaver(path)
-    if save_all == True:
-        save_int = save_infl = save_keyw = True
-
-    if save_int:
-        saver.save_users_interests(network_model)
-    if save_infl:
-        saver.save_users_influence(network_model)
-    if save_keyw:
-        saver.save_items_keyw(topic_model)
-
-    saver.save_mapping(network_model)
-    saver.save_items_descript(topic_model)
-    saver.save_topics_descript(topic_model)
+from womg_core.utils.distributions import set_seed
+#from womg.utils.saver import TxtSaver
 
 
 
 def womg_main(graph=None,
               docs_path=None,
-              items_descr_path=None,
+              items_descr=None,
               numb_topics=15,
               numb_docs=None,
               numb_steps=6,
@@ -76,7 +53,7 @@ def womg_main(graph=None,
     Parameters
     ----------
     numb_topics : int
-        number of topics for documents' topic model and nodes' interests. Default 15.
+        number of topics in the topic model. Default 15. K<d
 
     numb_docs : int
         number of docs to be generated. Default 100
@@ -89,14 +66,15 @@ def womg_main(graph=None,
         Default 0.5
 
     gn_strength : float
-        god node influence stength at intial time step. Default 13
+        god node influence stength. Default 13
 
     infl_strength : float
         relative strength of influence with respect to the interests
         Default: 12.
 
     virality : float
-        exponent of the powerlaw distribution for documents viralities. Default=8
+        exponent of the powerlaw distribution for documents viralities.
+        P(x; a) = x^{-a}, 0 <= x <=1. Deafault a=1
 
 
     int_mode : str
@@ -182,59 +160,45 @@ def womg_main(graph=None,
         save all non-optional outputs
     '''
 
-    try:
-        set_seed(seed)
-        network_model = TN( graph=graph,
-                            numb_topics=numb_topics, homophily=homophily,
-                            weighted=weighted, directed=directed,
+    set_seed(seed)
+    topic_model = LDA(numb_topics=numb_topics,
+                      numb_docs=numb_docs,
+                      docs_path=docs_path,
+                      items_descr=items_descr,
+                      progress_bar=progress_bar)
+    topic_model.fit()
+    prop = womgc(graph=graph,
+                numb_topics=numb_topics,
+                numb_docs=numb_docs,
+                homophily=homophily,
+                weighted=weighted,
+                directed=directed,
+                interests_path=interests_path,
+                gn_strength=gn_strength,
+                infl_strength=infl_strength,
+                p=p, q=q,
+                num_walks=num_walks, walk_length=walk_length,
+                window_size=window_size,
+                workers=workers, iiter=iiter,
+                progress_bar=progress_bar,
+                beta=beta,
+                norm_prior=norm_prior,
+                alpha_value=alpha_value,
+                beta_value=beta_value,
+                prop_steps=prop_steps,
+                seed=seed,
+                items_descr=topic_model.items_descript,
+                virality_exp=virality_exp,
+                single_activator=single_activator,
+                virality_resistance=virality_resistance,
+                numb_steps=numb_steps,
+                path_out=path_out,
+                save_all=save_all,
+                save_int=save_int,
+                save_infl=save_infl,
+                save_keyw=save_keyw)
 
-                            interests_path=interests_path,
-                            gn_strength=gn_strength,
-                            infl_strength=infl_strength,
-                            p=p, q=q,
-                            num_walks=num_walks, walk_length=walk_length,
-                            window_size=window_size,
-                            workers=workers, iiter=iiter,
-                            progress_bar=progress_bar,
-                            beta=beta,
-                            norm_prior=norm_prior,
-                            alpha_value=alpha_value,
-                            beta_value=beta_value,
-                            prop_steps=prop_steps,
-                            seed=seed)
-        network_model.network_setup(int_mode=int_mode)
-
-        topic_model = LDA(numb_topics=numb_topics,
-                          numb_docs=numb_docs,
-                          docs_path=docs_path,
-                          items_descr_path=items_descr_path,
-                          progress_bar=progress_bar)
-        topic_model.fit()
-        #print(virality_exp)
-        topic_model.set_docs_viralities(virality_exp=virality_exp)
-
-        diffusion_model = TLT(network_model=network_model,
-                              topic_model=topic_model,
-                              path_out=path_out,
-                              progress_bar=progress_bar,
-                              single_activator=single_activator,
-                              virality_resistance=virality_resistance)
-        diffusion_model.diffusion_setup()
-        diffusion_model.run(numb_steps=numb_steps)
-        #diffusion_model.save_threshold_values(path_out)
-        propagation = Propagation(network_model,
-                                  topic_model,
-                                  diffusion_model)
-    finally:
-        save(network_model=network_model,
-             topic_model=topic_model,
-             diffusion_model=diffusion_model,
-             path=path_out,
-             save_all=save_all,
-             save_int=save_int,
-             save_infl=save_infl,
-             save_keyw=save_keyw)
-    return propagation
+    return prop
 
 @click.command()
 @click.option('--topics', metavar='K', default=15,
@@ -280,7 +244,7 @@ def womg_main(graph=None,
 
 @click.option('--docs_folder', metavar='DOCS', default=None,
                     help='Input  path of the documents folder', type=str)
-@click.option('--items_descr_path', default=None,
+@click.option('--items_descr', default=None,
                     help='Input  path items description file representing each item in the topics space. Format: topic_index [topic-dim vec]', type=str)
 @click.option('--output', default=None, help='Outputs path')
 @click.option('--seed', help='Seed (int) for random distribution extractions',
@@ -340,7 +304,7 @@ def womg_main(graph=None,
                     default=False)
 
 def main_cli(graph,
-             items_descr_path,
+             items_descr,
              topics, docs, steps, homophily,
              virality_exp,
              virality_resistance,
@@ -377,7 +341,7 @@ def main_cli(graph,
     '''
     womg_main(graph=graph,
               docs_path=docs_folder,
-              items_descr_path=items_descr_path,
+              items_descr=items_descr,
               numb_topics=topics, numb_docs=docs,
               numb_steps=steps, homophily=homophily,
               gn_strength=gn_strength,
